/*
// UNIT TESTS OF THE BOT

INPUT: none


OUTPUT: ir sensor array in cm : (fl, fr, l, r, bl, br) from front left to back right

( 165, 69, 342, 342, 203, 82)
( 184, 71, 379, 359, 182, 82)
( 167, 69, 379, 441, 209, 85)
( 162, 68, 379, 402, 224, 82)
( 165, 69, 333, 342, 206, 82)

*/


#include <SharpIR.h>

/* Long Range IR Sensors */
#define IR_FRONT_LEFT         A5
#define IR_FRONT_RIGHT        A4
#define IR_LEFT               A3
#define IR_RIGHT              A2
#define IR_BACK_LEFT          A1
#define IR_BACK_RIGHT         A0


#define LONG_RANGE_IR_SENSOR  20150
#define MED_RANGE_IR_SENSOR   1080



/* Instances */
SharpIR IR_FL(IR_FRONT_LEFT, LONG_RANGE_IR_SENSOR);
SharpIR IR_FR(IR_FRONT_RIGHT, LONG_RANGE_IR_SENSOR);
SharpIR IR_L(IR_LEFT, MED_RANGE_IR_SENSOR);
SharpIR IR_R(IR_RIGHT, MED_RANGE_IR_SENSOR);
SharpIR IR_BL(IR_BACK_LEFT, LONG_RANGE_IR_SENSOR);
SharpIR IR_BR(IR_BACK_RIGHT, LONG_RANGE_IR_SENSOR);

/* Setup function */
void setup() {
  Serial.begin( 250000 );
  pinMode( IR_FRONT_LEFT, INPUT);
  pinMode( IR_FRONT_RIGHT, INPUT);
  pinMode( IR_LEFT, INPUT);
  pinMode( IR_RIGHT, INPUT);
  pinMode( IR_BACK_LEFT, INPUT);
  pinMode( IR_BACK_RIGHT, INPUT);
}

/* Infinite loop */
void loop() {
  /* Check for obstacles */
  Serial.print( "( " );
  Serial.print( IR_FL.distance() );
  Serial.print( ", " );
  Serial.print( IR_FR.distance() );
  Serial.print( ", " );
  Serial.print( IR_L.distance() );
  Serial.print( ", " );
  Serial.print( IR_R.distance() );
  Serial.print( ", " );
  Serial.print( IR_BL.distance() );
  Serial.print( ", " );
  Serial.print( IR_BR.distance() );
  Serial.print( ")\n" );

  /* Avoid reading before the new distance is sampled */
  delay( 100 );
}
